==> kvpnc-trinity-14.0.13.tar.xz: kvpnc-trinity-14.0.13/src/mainview.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef __MAINVIEW_H__
#define __MAINVIEW_H__

#include <tqstring.h>
#include <tqwidget.h>
#include <kprocess.h>
#include <tqprocess.h>
#include <tdeconfig.h>
#include "mainviewbase.h"
#include "kvpnckicker.h"
#include "debugoutputtextedit.h"

// ID for statusbar
#define ID_STATUS_MSG 1
#define ID_CONNECTION_MSG 2

class MainView : public MainViewBase {

public:
	MainView( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );

	~MainView();
	DebugOutputTextEdit *DebugOutput;

};

#endif

==> kvpnc-trinity_14.1.6~pre2.orig.tar.xz: kvpnc-trinity-14.1.6~pre2+b555b77b/src/mainview.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef __MAINVIEW_H__
#define __MAINVIEW_H__

#include <tqstring.h>
#include <tqwidget.h>
#include <kprocess.h>
#include <tqprocess.h>
#include <tdeconfig.h>
#include "mainviewbase.h"
#include "kvpnckicker.h"
#include "debugoutputtextedit.h"

// ID for statusbar
#define ID_STATUS_MSG 1
#define ID_CONNECTION_MSG 2

class MainView : public MainViewBase {

public:
	MainView( TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );

	~MainView();
	DebugOutputTextEdit *DebugOutput;

};

#endif
